package Sah::Schemas::Net;

our $DATE = '2018-06-05'; # DATE
our $VERSION = '0.006'; # VERSION

1;
# ABSTRACT: Schemas related to network (IP address, hostnames, etc)

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::Schemas::Net - Schemas related to network (IP address, hostnames, etc)

=head1 VERSION

This document describes version 0.006 of Sah::Schemas::Net (from Perl distribution Sah-Schemas-Net), released on 2018-06-05.

=head1 DESCRIPTION

Todo:

 net::ipv6
 net::ip
 net::ip_range
 net::ipv4_range
 net::ipv6_range

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Net>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Net>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Net>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Sah> - specification

L<Data::Sah>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
